##  Importing Diagrams from a Device
Currently, diagram editors only support importing diagrams in the following formats:
  * .drawio (the diagram format used by [draw.io![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fdiagrams.net%2F "http://diagrams.net/"))
  * Lucidchart diagram files
  * .vsdx (newer Visio files) - without multiple tabs (only the first tab can be imported) and layers.
  * PNG image files (with or without the embedded XML of a .drawio diagram)
  * SVG images
  * JPEG images


To import a diagram, do the following:
  1. Go to the Diagrams tab, and choose New Diagram or open an existing diagram.
  2. Go to File > Import from.
  3. Choose Device to browse files on your device. ![The File menu with Import from Device option highlighted in draw.io.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745d1a67a441014bf0beb22b1056c32_LowRes.png)
  4. Select the file that you want to import and choose Open.
